Mercurio
=========

Send email with python, my way

A simple class to send email with python, managing
smtp, attachments and mimetypes, multiple recipients,
attachments with a specific content id (to html email templating)...